pub struct BufferCollectionInfo {
pub settings: Option<SingleBufferSettings>,
pub buffers: Option<Vec<VmoBuffer>>,
pub buffer_collection_id: Option<u64>,
}Expand description
Information about a buffer collection and its buffers.
When adding fields to this table, see also fuchsia.sysmem2/Allocator.GetVmoInfo, redacted_buffer_collection_info, and RedactBufferCollectionInfo. Consider whether a client with only ZX_RIGHT_TRANSFER right on a sysmem vmo handle, calling GetVmoInfo, should be given the information in the new field, or whether it should be un-set during redaction. GetVmoInfo is analogous to zx_object_get_info with topic ZX_INFO_VMO, which doesn’t require the VMO handle to have any rights - just needs to be a handle to a VMO. Fields that are necessary to correctly use a single sysmem VMO in isolation are generally ok (but still think about it field by field). Fields that are not necessary to correctly use a single sysmem VMO in isolation should probably be redacted for GetVmoInfo redacted_buffer_collection_info.
Fields
settings: Option<SingleBufferSettings>buffers: Option<Vec<VmoBuffer>>buffer_collection_id: Option<u64>Trait Implementations
Sourceimpl Debug for BufferCollectionInfo
impl Debug for BufferCollectionInfo
Sourceimpl Default for BufferCollectionInfo
impl Default for BufferCollectionInfo
Sourcefn default() -> BufferCollectionInfo
fn default() -> BufferCollectionInfo
Sourceimpl<___E> Encode<BufferCollectionInfo<'static>, ___E> for BufferCollectionInfowhere
___E: Encoder + ?Sized + HandleEncoder,
impl<___E> Encode<BufferCollectionInfo<'static>, ___E> for BufferCollectionInfowhere
___E: Encoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<BufferCollectionInfo<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<BufferCollectionInfo<'static>>, _: (), ) -> Result<(), EncodeError>
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<BufferCollectionInfo<'de>> for BufferCollectionInfo
impl<'de> FromWire<BufferCollectionInfo<'de>> for BufferCollectionInfo
Sourcefn from_wire(wire_: BufferCollectionInfo<'de>) -> Self
fn from_wire(wire_: BufferCollectionInfo<'de>) -> Self
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for BufferCollectionInfo
impl PartialEq for BufferCollectionInfo
Sourcefn eq(&self, other: &BufferCollectionInfo) -> bool
fn eq(&self, other: &BufferCollectionInfo) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BufferCollectionInfo