pub struct BufferMemorySettings {
pub size_bytes: Option<u64>,
pub is_physically_contiguous: Option<bool>,
pub is_secure: Option<bool>,
pub coherency_domain: Option<CoherencyDomain>,
pub heap: Option<Heap>,
pub raw_vmo_size: Option<u64>,
}Expand description
These are memory-related settings for all buffers of a buffer collection.
Fields
size_bytes: Option<u64>is_physically_contiguous: Option<bool>is_secure: Option<bool>coherency_domain: Option<CoherencyDomain>heap: Option<Heap>raw_vmo_size: Option<u64>Trait Implementations
Sourceimpl Clone for BufferMemorySettings
impl Clone for BufferMemorySettings
Sourcefn clone(&self) -> BufferMemorySettings
fn clone(&self) -> BufferMemorySettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BufferMemorySettings
impl Debug for BufferMemorySettings
Sourceimpl Default for BufferMemorySettings
impl Default for BufferMemorySettings
Sourcefn default() -> BufferMemorySettings
fn default() -> BufferMemorySettings
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<BufferMemorySettings<'static>, ___E> for &'a BufferMemorySettingswhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<BufferMemorySettings<'static>, ___E> for &'a BufferMemorySettingswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<BufferMemorySettings<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<BufferMemorySettings<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BufferMemorySettings<'static>, ___E> for BufferMemorySettingswhere
___E: Encoder + ?Sized,
impl<___E> Encode<BufferMemorySettings<'static>, ___E> for BufferMemorySettingswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<BufferMemorySettings<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<BufferMemorySettings<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<BufferMemorySettings<'de>> for BufferMemorySettings
impl<'de> FromWire<BufferMemorySettings<'de>> for BufferMemorySettings
Sourcefn from_wire(wire_: BufferMemorySettings<'de>) -> BufferMemorySettings
fn from_wire(wire_: BufferMemorySettings<'de>) -> BufferMemorySettings
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<BufferMemorySettings<'de>> for BufferMemorySettings
impl<'de> FromWireRef<BufferMemorySettings<'de>> for BufferMemorySettings
Sourcefn from_wire_ref(wire: &BufferMemorySettings<'de>) -> BufferMemorySettings
fn from_wire_ref(wire: &BufferMemorySettings<'de>) -> BufferMemorySettings
Converts the given reference to this type.
Sourceimpl Hash for BufferMemorySettings
impl Hash for BufferMemorySettings
Sourceimpl Ord for BufferMemorySettings
impl Ord for BufferMemorySettings
Sourcefn cmp(&self, other: &BufferMemorySettings) -> Ordering
fn cmp(&self, other: &BufferMemorySettings) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BufferMemorySettings
impl PartialEq for BufferMemorySettings
Sourcefn eq(&self, other: &BufferMemorySettings) -> bool
fn eq(&self, other: &BufferMemorySettings) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BufferMemorySettings
impl PartialOrd for BufferMemorySettings
impl Eq for BufferMemorySettings
impl StructuralPartialEq for BufferMemorySettings