pub struct BufferCollectionConstraints {
pub usage: Option<BufferUsage>,
pub min_buffer_count_for_camping: Option<u32>,
pub min_buffer_count_for_dedicated_slack: Option<u32>,
pub min_buffer_count_for_shared_slack: Option<u32>,
pub min_buffer_count: Option<u32>,
pub max_buffer_count: Option<u32>,
pub buffer_memory_constraints: Option<BufferMemoryConstraints>,
pub image_format_constraints: Option<Vec<ImageFormatConstraints>>,
}Expand description
Constraints on allocated buffers and, optionally, constraints on images stored in the buffers. These constraints can be specified per-participant. The sysmem service implements aggregation of constraints from multiple participants.
Fields
usage: Option<BufferUsage>min_buffer_count_for_camping: Option<u32>min_buffer_count_for_dedicated_slack: Option<u32>min_buffer_count: Option<u32>max_buffer_count: Option<u32>buffer_memory_constraints: Option<BufferMemoryConstraints>image_format_constraints: Option<Vec<ImageFormatConstraints>>Trait Implementations
Sourceimpl Clone for BufferCollectionConstraints
impl Clone for BufferCollectionConstraints
Sourcefn clone(&self) -> BufferCollectionConstraints
fn clone(&self) -> BufferCollectionConstraints
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BufferCollectionConstraints
impl Debug for BufferCollectionConstraints
Sourceimpl Default for BufferCollectionConstraints
impl Default for BufferCollectionConstraints
Sourcefn default() -> BufferCollectionConstraints
fn default() -> BufferCollectionConstraints
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<BufferCollectionConstraints<'static>, ___E> for &'a BufferCollectionConstraintswhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<BufferCollectionConstraints<'static>, ___E> for &'a BufferCollectionConstraintswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<BufferCollectionConstraints<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<BufferCollectionConstraints<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BufferCollectionConstraints<'static>, ___E> for BufferCollectionConstraintswhere
___E: Encoder + ?Sized,
impl<___E> Encode<BufferCollectionConstraints<'static>, ___E> for BufferCollectionConstraintswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<BufferCollectionConstraints<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<BufferCollectionConstraints<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<BufferCollectionConstraints<'de>> for BufferCollectionConstraints
impl<'de> FromWire<BufferCollectionConstraints<'de>> for BufferCollectionConstraints
Sourcefn from_wire(
wire_: BufferCollectionConstraints<'de>,
) -> BufferCollectionConstraints
fn from_wire( wire_: BufferCollectionConstraints<'de>, ) -> BufferCollectionConstraints
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<BufferCollectionConstraints<'de>> for BufferCollectionConstraints
impl<'de> FromWireRef<BufferCollectionConstraints<'de>> for BufferCollectionConstraints
Sourcefn from_wire_ref(
wire: &BufferCollectionConstraints<'de>,
) -> BufferCollectionConstraints
fn from_wire_ref( wire: &BufferCollectionConstraints<'de>, ) -> BufferCollectionConstraints
Converts the given reference to this type.
Sourceimpl PartialEq for BufferCollectionConstraints
impl PartialEq for BufferCollectionConstraints
Sourcefn eq(&self, other: &BufferCollectionConstraints) -> bool
fn eq(&self, other: &BufferCollectionConstraints) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BufferCollectionConstraints