pub struct FormatCosts {
pub format_costs: Option<Vec<FormatCostEntry>>,
}Expand description
This is the root of the persistent fidl in a format costs file. The format costs files are read by the assembly tool and merged into the single sysmem_config.persistent_fidl file in the sysmem domain config (see Config above).
Normally json[5] would be preferable for config, but we generate this config in rust using FIDL types (to avoid repetition and to take advantage of FIDL rust codegen), and there’s no json schema for FIDL types.
While the resulting sysmem_config.persistent_fidl is a single file that can contain multiple aspects of sysmem config, in contrast a format costs file contains only format costs. We don’t mind having more separate files during the build, but it’s nice to get sysmem’s domain config down to a single file on-device.
Fields
format_costs: Option<Vec<FormatCostEntry>>Trait Implementations
Sourceimpl Clone for FormatCosts
impl Clone for FormatCosts
Sourcefn clone(&self) -> FormatCosts
fn clone(&self) -> FormatCosts
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FormatCosts
impl Debug for FormatCosts
Sourceimpl Default for FormatCosts
impl Default for FormatCosts
Sourcefn default() -> FormatCosts
fn default() -> FormatCosts
Sourceimpl<'a, ___E> Encode<FormatCosts<'static>, ___E> for &'a FormatCostswhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<FormatCosts<'static>, ___E> for &'a FormatCostswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<FormatCosts<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<FormatCosts<'static>>, _: (), ) -> Result<(), EncodeError>
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FormatCosts<'static>, ___E> for FormatCostswhere
___E: Encoder + ?Sized,
impl<___E> Encode<FormatCosts<'static>, ___E> for FormatCostswhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<FormatCosts<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<FormatCosts<'static>>, _: (), ) -> Result<(), EncodeError>
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<FormatCosts<'de>> for FormatCosts
impl<'de> FromWire<FormatCosts<'de>> for FormatCosts
Sourcefn from_wire(wire_: FormatCosts<'de>) -> FormatCosts
fn from_wire(wire_: FormatCosts<'de>) -> FormatCosts
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<FormatCosts<'de>> for FormatCosts
impl<'de> FromWireRef<FormatCosts<'de>> for FormatCosts
Sourcefn from_wire_ref(wire: &FormatCosts<'de>) -> FormatCosts
fn from_wire_ref(wire: &FormatCosts<'de>) -> FormatCosts
Sourceimpl PartialEq for FormatCosts
impl PartialEq for FormatCosts
Sourcefn eq(&self, other: &FormatCosts) -> bool
fn eq(&self, other: &FormatCosts) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FormatCosts
impl PartialOrd for FormatCosts
impl StructuralPartialEq for FormatCosts